import React, { useState } from "react";
import {
  MdDownload,
  MdExpandLess,
  MdExpandMore,
  MdRefresh,
  MdOutlineDelete,
} from "react-icons/md";

import FileInput from "./FileInput";
export function FileView({
  generateFile,
  grammar,
  getFile,
  fileToGrammar,
  deleteFile,
  deleteFilesFromGrammar,
}) {
  const [xml, setXml] = useState(false);
  const [more, setMore] = useState(false);
  const [fileInput, setFileInput] = useState(false);
  const [file, setFile] = useState({});
  const [text, setText] = useState("");
  const fileAdd = (file, xml, save, diff) => {
    fileToGrammar(file, xml, grammar.id, save, diff);
  };
  return (
    <>
      <p>
        <button onClick={() => setXml(!xml)}>{xml ? "JSGF" : "XML"}</button>{" "}
        <button onClick={() => generateFile(xml, grammar.id)}>
          GENERATE {xml ? "XML" : "JSGF"}{" "}
        </button>{" "}
        <a
          href={
            (window.location.hostname == "localhost" ? "http://localhost:8080":"") +
            "/api/files/" +
            grammar.id +
            "/new/" +
            (xml ? "xml" : "jsgf") +
            "/download"
          }
        >
          <MdDownload />
        </a>{" "}
      </p>
      {(xml ? grammar.xmlGen : grammar.jsgfGen) && (
        <p>
          <textarea 
            className="transparent big"
            readOnly={true}
            rows="15"
            cols="50"
            value={xml ? grammar.xmlGen : grammar.jsgfGen}
          />
        </p>
      )}
      <button onClick={() => setFileInput(!fileInput)}>
        {fileInput ? "CANCEL" : "ADD FILE"}
      </button>
      {"  "}
      {fileInput && (
        <FileInput
          fileAdd={fileAdd}
          file={file}
          setFile={setFile}
          setText={setText}
          text={text}
          newDiff={true}
        />
      )}
      <div className="cell">{grammar.files.length + " files"}</div>
      <MdOutlineDelete onClick={() => deleteFilesFromGrammar(grammar.id)} />
      {more ? (
        <MdExpandLess onClick={() => setMore(!more)} />
      ) : (
        <MdExpandMore onClick={() => setMore(!more)} />
      )}

      {more && (
        <div className="table">
          {grammar.files.map((file) => (
            <div className="cell" key={file.id}>
              <table>
                <thead>
                  <tr>
                    <th>Generated</th>
                    <th>Xml</th>
                    <th>Size</th>
                    <th rowSpan={2}>
                      <a
                        href={
                          //test production difference
                          (window.location.hostname == "localhost" ?
                            "http://localhost:8080":"") +
                          "/api/files/" +
                          +file.id +
                          "/download"
                        }
                      >
                        <MdDownload />
                      </a>
                    </th>
                    <th rowSpan={2}>
                      <MdRefresh onClick={() => getFile(file.id, grammar.id)} />
                    </th>
                    <th rowSpan={2}>
                      <MdOutlineDelete
                        onClick={() => deleteFile(file.id, grammar.id)}
                      />
                    </th>
                  </tr>
                </thead>
                <tbody>
                  <tr>
                    <td>{file.generated ? "✓" : "❌"}</td>
                    <td>{file.xml ? "✓" : "❌"}</td>
                    <td>{file.size + " B"}</td>
                  </tr>
                  <tr>
                    <td colSpan={5}>
                      {file.content && (
                        <textarea
                          className="transparent big"
                          readOnly={true}
                          rows="15"
                          cols="50"
                          value={file.content}
                        />
                      )}
                    </td>
                  </tr>
                </tbody>
              </table>
            </div>
          ))}
        </div>
      )}
    </>
  );
}
